package
Version:
v0.0.0-...-3017115
Opens a new window with list of versions in this module.
Published: Feb 17, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Post struct {
Id bson.ObjectId `json:"id" bson:"_id"`
Caption string `json:"caption" bson:"caption"`
Image_URL string `json:"image_url" bson:"image_url"`
Posted_Timestamp string `json:"password" bson:"password"`
}
type User struct {
Id bson.ObjectId `json:"id" bson:"_id"`
Name string `json:"name" bson:"name"`
Email string `json:"email" bson:"email"`
Password string `json:"password" bson:"password"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.